@@ -3,7 +3,6 @@ import os
 import os.path as osp
 import numpy as np
 import pandas as pd
-import shutil
 import zipfile
 import requests
 from clint.textui import progress
@@ -12,27 +11,29 @@ from tgb.utils.info import (
     PROJ_DIR,
     DATA_URL_DICT,
     DATA_NUM_CLASSES,
+    DATA_VERSION_DICT,
     DATA_EVAL_METRIC_DICT,
     BColors,
 )
-from tgb.utils.utils import save_pkl, load_pkl
+from tgb.utils.utils import save_pkl, load_pkl, vprint
 from tgb.utils.pre_process import (
     load_label_dict,
     load_edgelist_sr,
+    load_edgelist_token,
     load_edgelist_datetime,
     load_trade_label_dict,
     load_edgelist_trade,
 )
 
 
-#! can retire meta_dict as input to the class
-class NodePropertyDataset(object):
+class NodePropPredDataset(object):
     def __init__(
         self,
         name: str,
-        root: Optional[str] = "datasets",
+        root: str = "datasets",
         meta_dict: Optional[dict] = None,
         preprocess: Optional[bool] = True,
+        download: Optional[bool] = True, 
     ) -> None:
         r"""Dataset class for the node property prediction task. Stores meta information about each dataset such as evaluation metrics etc.
         also automatically pre-processes the dataset.
@@ -45,6 +46,7 @@ class NodePropertyDataset(object):
             root: root directory to store the dataset folder
             meta_dict: dictionary containing meta information about the dataset, should contain key 'dir_name' which is the name of the dataset folder
             preprocess: whether to pre-process the dataset
+            download: whether to download the dataset or not (default: True)
         Returns:
             None
         """
@@ -54,16 +56,13 @@ class NodePropertyDataset(object):
             self.url = DATA_URL_DICT[self.name]
         else:
             self.url = None
-            print(f"Dataset {self.name} url not found, download not supported yet.")
 
         # check if the evaluatioin metric are specified
         if self.name in DATA_EVAL_METRIC_DICT:
             self.metric = DATA_EVAL_METRIC_DICT[self.name]
         else:
             self.metric = None
-            print(
-                f"Dataset {self.name} default evaluation metric not found, it is not supported yet."
-            )
+            raise ValueError(f"Dataset {self.name} default evaluation metric not found, it is not supported yet.")
 
         root = PROJ_DIR + root
 
@@ -76,9 +75,11 @@ class NodePropertyDataset(object):
         self.meta_dict = meta_dict
         if "fname" not in self.meta_dict:
             self.meta_dict["fname"] = self.root + "/" + self.name + "_edgelist.csv"
-            self.meta_dict["nodefile"] = (
-                self.root + "/" + self.name + "_node_labels.csv"
-            )
+            self.meta_dict["nodefile"] = self.root + "/" + self.name + "_node_labels.csv"
+
+         #! version check
+        self.version_passed = True
+        self._version_check()
 
         self._num_classes = DATA_NUM_CLASSES[self.name]
 
@@ -86,10 +87,20 @@ class NodePropertyDataset(object):
         self._node_feat = None
         self._edge_feat = None
         self._full_data = None
-        self.download()
+
+        if download:
+            self.download()
+        else:
+            if osp.exists(self.meta_dict["fname"]):
+                dir_name = self.meta_dict["fname"]
+                vprint(f"files found in {dir_name}")
+            else:
+                dir_name = self.meta_dict["fname"]
+                raise FileNotFoundError(f"Directory not found at {dir_name}, please download the dataset")
+            
         # check if the root directory exists, if not create it
         if osp.isdir(self.root):
-            print("Dataset directory is ", self.root)
+            vprint("Dataset directory is ", self.root)
         else:
             raise FileNotFoundError(f"Directory not found at {self.root}")
 
@@ -98,6 +109,26 @@ class NodePropertyDataset(object):
 
         self.label_ts_idx = 0  # index for which node lables to return now
 
+    def _version_check(self) -> None:
+        r"""Implement Version checks for dataset files
+        updates the file names based on the current version number
+        prompt the user to download the new version via self.version_passed variable
+        """
+        if (self.name in DATA_VERSION_DICT):
+            version = DATA_VERSION_DICT[self.name]
+        else:
+            raise ValueError(f"Dataset {self.name} version number not found.")
+        
+        if (version > 1):
+            #* check if current version is outdated
+            self.meta_dict["fname"] = self.root + "/" + self.name + "_edgelist_v" + str(int(version)) + ".csv"
+            self.meta_dict["nodefile"] = self.root + "/" + self.name + "_node_labels_v" + str(int(version)) + ".csv"
+            
+            if (not osp.exists(self.meta_dict["fname"])):
+                vprint(f"Dataset {self.name} version {int(version)} not found, Please download the latest version of the dataset.")
+                self.version_passed = False
+                return None
+
     def download(self) -> None:
         r"""
         downloads this dataset from url
@@ -109,51 +140,40 @@ class NodePropertyDataset(object):
         if osp.exists(self.meta_dict["fname"]) and osp.exists(
             self.meta_dict["nodefile"]
         ):
-            print("file found, skipping download")
+            dir_name = self.meta_dict["fname"]
+            vprint(f"files found in {dir_name}")
             return
 
         else:
-            inp = input(
-                "Will you download the dataset(s) now? (y/N)\n"
-            ).lower()  # ask if the user wants to download the dataset
-            if inp == "y":
-                print(
-                    f"{BColors.WARNING}Download started, this might take a while . . . {BColors.ENDC}"
-                )
-                print(f"Dataset title: {self.name}")
+            vprint(
+                f"{BColors.WARNING}Download started, this might take a while . . . {BColors.ENDC}"
+            )
+            vprint(f"Dataset title: {self.name}")
 
-                if self.url is None:
-                    raise Exception(
-                        "Dataset url not found, download not supported yet."
-                    )
-                else:
-                    r = requests.get(self.url, stream=True)
-                    if osp.isdir(self.root):
-                        print("Dataset directory is ", self.root)
-                    else:
-                        os.makedirs(self.root)
-
-                    path_download = self.root + "/" + self.name + ".zip"
-                    with open(path_download, "wb") as f:
-                        total_length = int(r.headers.get("content-length"))
-                        for chunk in progress.bar(
-                            r.iter_content(chunk_size=1024),
-                            expected_size=(total_length / 1024) + 1,
-                        ):
-                            if chunk:
-                                f.write(chunk)
-                                f.flush()
-                    # for unzipping the file
-                    with zipfile.ZipFile(path_download, "r") as zip_ref:
-                        zip_ref.extractall(self.root)
-                    print(f"{BColors.OKGREEN}Download completed {BColors.ENDC}")
+            if self.url is None:
+                raise ValueError(f"Dataset {self.name} url not found, download not supported yet.")
             else:
-                raise Exception(
-                    BColors.FAIL
-                    + "Data not found error, download "
-                    + self.name
-                    + " failed"
-                )
+                r = requests.get(self.url, stream=True)
+                if osp.isdir(self.root):
+                    vprint("Dataset directory is ", self.root)
+                else:
+                    os.makedirs(self.root)
+
+                path_download = self.root + "/" + self.name + ".zip"
+                with open(path_download, "wb") as f:
+                    total_length = int(r.headers.get("content-length"))
+                    for chunk in progress.bar(
+                        r.iter_content(chunk_size=1024),
+                        expected_size=(total_length / 1024) + 1,
+                    ):
+                        if chunk:
+                            f.write(chunk)
+                            f.flush()
+                # for unzipping the file
+                with zipfile.ZipFile(path_download, "r") as zip_ref:
+                    zip_ref.extractall(self.root)
+                vprint(f"{BColors.OKGREEN}Download completed {BColors.ENDC}")
+          
 
     def generate_processed_files(
         self,
@@ -167,41 +187,53 @@ class NodePropertyDataset(object):
         OUT_DF = self.root + "/" + "ml_{}.pkl".format(self.name)
         OUT_NODE_DF = self.root + "/" + "ml_{}_node.pkl".format(self.name)
         OUT_LABEL_DF = self.root + "/" + "ml_{}_label.pkl".format(self.name)
+        OUT_EDGE_FEAT = self.root + "/" + "ml_{}.pkl".format(self.name + "_edge")
 
-        # * logic for subreddits, as node label file is too big to store on disc
-        if self.name == "subreddits":
-            if osp.exists(OUT_DF) and osp.exists(OUT_NODE_DF):
+        # * logic for large datasets, as node label file is too big to store on disc
+        if self.name == "tgbn-reddit" or self.name == "tgbn-token":
+            if osp.exists(OUT_DF) and osp.exists(OUT_NODE_DF) and osp.exists(OUT_EDGE_FEAT):
                 df = pd.read_pickle(OUT_DF)
+                edge_feat = load_pkl(OUT_EDGE_FEAT)
+                if (self.name == "tgbn-token"):
+                    #! taking log normalization for numerical stability
+                    vprint ("applying log normalization for weights in tgbn-token")
+                    edge_feat[:,0] = np.log(edge_feat[:,0])
                 node_ids = load_pkl(OUT_NODE_DF)
                 labels_dict = load_pkl(OUT_LABEL_DF)
                 node_label_dict = load_label_dict(
                     self.meta_dict["nodefile"], node_ids, labels_dict
                 )
-                return df, node_label_dict
+                return df, node_label_dict, edge_feat
 
         # * load the preprocessed file if possible
-        if osp.exists(OUT_DF) and osp.exists(OUT_NODE_DF):
-            print("loading processed file")
+        if osp.exists(OUT_DF) and osp.exists(OUT_NODE_DF) and osp.exists(OUT_EDGE_FEAT):
+            vprint(f"loading processed file from {OUT_DF}, edge features from {OUT_EDGE_FEAT}, node info from {OUT_NODE_DF}.")
             df = pd.read_pickle(OUT_DF)
             node_label_dict = load_pkl(OUT_NODE_DF)
+            edge_feat = load_pkl(OUT_EDGE_FEAT)
         else:  # * process the file
-            print("file not processed, generating processed file")
-            if self.name == "subreddits":
+            vprint("file not processed, generating processed file")
+            if self.name == "tgbn-reddit":
                 df, edge_feat, node_ids, labels_dict = load_edgelist_sr(
                     self.meta_dict["fname"], label_size=self._num_classes
                 )
-            elif self.name == "lastfmgenre":
+            elif self.name == "tgbn-token":
+                df, edge_feat, node_ids, labels_dict = load_edgelist_token(
+                    self.meta_dict["fname"], label_size=self._num_classes
+                )
+            elif self.name == "tgbn-genre":
                 df, edge_feat, node_ids, labels_dict = load_edgelist_datetime(
                     self.meta_dict["fname"], label_size=self._num_classes
                 )
-            elif self.name == "un_trade":
+            elif self.name == "tgbn-trade":
                 df, edge_feat, node_ids = load_edgelist_trade(
                     self.meta_dict["fname"], label_size=self._num_classes
                 )
 
             df.to_pickle(OUT_DF)
+            save_pkl(edge_feat, OUT_EDGE_FEAT)
 
-            if self.name == "un_trade":
+            if self.name == "tgbn-trade":
                 node_label_dict = load_trade_label_dict(
                     self.meta_dict["nodefile"], node_ids
                 )
@@ -211,15 +243,15 @@ class NodePropertyDataset(object):
                 )
 
             if (
-                self.name != "subreddits"
+                self.name != "tgbn-reddit" and self.name != "tgbn-token"
             ):  # don't save subreddits on disc, the node label file is too big
                 save_pkl(node_label_dict, OUT_NODE_DF)
             else:
                 save_pkl(node_ids, OUT_NODE_DF)
                 save_pkl(labels_dict, OUT_LABEL_DF)
             
-            print("file processed and saved")
-        return df, node_label_dict
+            vprint("file processed and saved")
+        return df, node_label_dict, edge_feat
 
     def pre_process(self) -> None:
         """
@@ -231,13 +263,14 @@ class NodePropertyDataset(object):
         if ("fname" not in self.meta_dict) or ("nodefile" not in self.meta_dict):
             raise Exception("meta_dict does not contain all required filenames")
 
-        df, node_label_dict = self.generate_processed_files()
+        df, node_label_dict, edge_feat = self.generate_processed_files()
         sources = np.array(df["u"])
         destinations = np.array(df["i"])
         timestamps = np.array(df["ts"])
         edge_idxs = np.array(df["idx"])
         edge_label = np.ones(sources.shape[0])
-        self._edge_feat = np.array(df["w"])
+        #self._edge_feat = np.array(df["w"])
+        self._edge_feat = edge_feat
 
         full_data = {
             "sources": sources,
@@ -246,6 +279,7 @@ class NodePropertyDataset(object):
             "edge_idxs": edge_idxs,
             "edge_feat": self._edge_feat,
             "edge_label": edge_label,
+            "node_label_dict": node_label_dict,
         }
         self._full_data = full_data
 
@@ -303,7 +337,7 @@ class NodePropertyDataset(object):
             source_idx: node ids
             labels: the stacked label vectors
         """
-        if self.label_ts_idx >= (self.label_ts.shape[0] - 1):
+        if self.label_ts_idx >= (self.label_ts.shape[0]):
             # for query that are after the last batch of labels
             return None
         else:
@@ -337,7 +371,10 @@ class NodePropertyDataset(object):
         Returns:
             ts: int, the timestamp of the node labels
         """
-        return self.label_ts[self.label_ts_idx]
+        if (self.label_ts_idx >= self.label_ts.shape[0]):
+            return self.label_ts[-1]
+        else:
+            return self.label_ts[self.label_ts_idx]
 
     @property
     def num_classes(self) -> int:
@@ -376,6 +413,15 @@ class NodePropertyDataset(object):
             edge_feat: np.ndarray, [E, feat_dim] or None if there is no edge feature
         """
         return self._edge_feat
+    
+    @property
+    def node_label_dict(self) -> Dict[int, Dict[int, Any]]:
+        r"""
+        Returns the node label dictionary of the dataset with {timestamp: {node_id: label_vec}}
+        Returns:
+            label_dict: Dict[int, Dict[int, Any]], the node label dictionary
+        """
+        return self.label_dict
 
     @property
     def full_data(self) -> Dict[str, Any]:
@@ -429,8 +475,8 @@ class NodePropertyDataset(object):
 
 def main():
     # download files
-    name = "un_trade"  # "subreddits" #"lastfmgenre"
-    dataset = NodePropertyDataset(name=name, root="datasets", preprocess=True)
+    name = "tgbn-trade" 
+    dataset = NodePropPredDataset(name=name, root="datasets", preprocess=True)
 
     dataset.node_feat
     dataset.edge_feat  # not the edge weights
