@@ -5,14 +5,406 @@ import pandas as pd
 import os.path as osp
 import time
 import csv
-from datetime import datetime, timedelta
+import datetime
+from datetime import date
+from tgb.utils.utils import vprint
+
+"""
+function to process node type for thg datasets
+"""
+
+def process_node_type(
+    fname: str,
+    node_ids,
+):
+    """
+    1. process the node type into integer
+    3. return a numpy array of node types with index corresponding to node id
+    """
+    node_feat = np.zeros(len(node_ids))
+    with open(fname, "r") as csv_file:
+        csv_reader = csv.reader(csv_file, delimiter=",")
+        idx = 0
+        # node_id,type
+        for row in tqdm(csv_reader):
+            if idx == 0:
+                idx += 1
+                continue
+            else:
+                nid = int(row[0])
+                try:
+                    node_type = int(row[1])
+                except:
+                    raise ValueError(row[1], " is not an integer thus can't be a node type for thg dataset")
+                try:
+                    node_id = node_ids[nid]
+                except:
+                    raise ValueError(nid, " is not a valid node id")
+                node_feat[node_id] = node_type
+    return node_feat
+
+"""
+functions for thgl-forum dataset
+"""
+def csv_to_forum_data(
+    fname: str,
+) -> pd.DataFrame:
+    r"""
+    used by thgl-forum dataset
+    convert the raw .csv data to pandas dataframe and numpy array
+    input .csv file format should be: timestamp, head, tail, relation type
+    Args:
+        fname: the path to the raw data
+    """
+    feat_size = 2
+    num_lines = sum(1 for line in open(fname)) - 1
+    vprint(f"number of lines counted: {num_lines} in {fname}")
+    u_list = np.zeros(num_lines)
+    i_list = np.zeros(num_lines)
+    ts_list = np.zeros(num_lines)
+    label_list = np.zeros(num_lines)
+    edge_type = np.zeros(num_lines)
+    feat_l = np.zeros((num_lines, feat_size))
+    idx_list = np.zeros(num_lines)
+    w_list = np.zeros(num_lines)
+    node_ids = {}
+    unique_id = 0
+
+    word_max = 10000
+    score_max = 10000
+
+    with open(fname, "r") as csv_file:
+        csv_reader = csv.reader(csv_file, delimiter=",")
+        idx = 0
+        #timestamp, head, tail, relation type
+        for row in tqdm(csv_reader):
+            if idx == 0:
+                idx += 1
+                continue
+            else:
+                #! ts,src,dst,relation_type,num_words,score
+                ts = int(row[0]) #converted to UNIX timestamp already 
+                src = int(row[1])
+                dst = int(row[2])
+                relation = int(row[3])
+                num_words = int(row[4])
+                score = int(row[5])
+                if src not in node_ids:
+                    node_ids[src] = unique_id
+                    unique_id += 1
+                if dst not in node_ids:
+                    node_ids[dst] = unique_id
+                    unique_id += 1
+                u = node_ids[src]
+                i = node_ids[dst]
+                u_list[idx - 1] = u
+                i_list[idx - 1] = i
+                ts_list[idx - 1] = ts
+                idx_list[idx - 1] = idx
+                w_list[idx - 1] = float(1)
+                edge_type[idx - 1] = relation
+                feat_l[idx - 1] = np.array([num_words/word_max, score/score_max])
+                idx += 1
+    return (
+        pd.DataFrame(
+            {
+                "u": u_list,
+                "i": i_list,
+                "ts": ts_list,
+                "label": label_list,
+                "idx": idx_list,
+                "w": w_list,
+                "edge_type": edge_type,
+            }
+        ),
+        feat_l,
+        node_ids,
+    )
+
+
+
+
+"""
+functions for thg dataset
+"""
+def csv_to_thg_data(
+    fname: str,
+) -> pd.DataFrame:
+    r"""
+    used by thgl-myket dataset
+    convert the raw .csv data to pandas dataframe and numpy array
+    input .csv file format should be: timestamp, head, tail, relation type
+    Args:
+        fname: the path to the raw data
+    """
+    feat_size = 1
+    num_lines = sum(1 for line in open(fname)) - 1
+    vprint(f"number of lines counted: {num_lines} in {fname}")
+    u_list = np.zeros(num_lines)
+    i_list = np.zeros(num_lines)
+    ts_list = np.zeros(num_lines)
+    label_list = np.zeros(num_lines)
+    edge_type = np.zeros(num_lines)
+    feat_l = np.zeros((num_lines, feat_size))
+    idx_list = np.zeros(num_lines)
+    w_list = np.zeros(num_lines)
+    node_ids = {}
+    unique_id = 0
+
+    with open(fname, "r") as csv_file:
+        csv_reader = csv.reader(csv_file, delimiter=",")
+        idx = 0
+        #timestamp, head, tail, relation type
+        for row in tqdm(csv_reader):
+            if idx == 0:
+                idx += 1
+                continue
+            else:
+                ts = int(row[0]) #converted to UNIX timestamp already 
+                src = int(row[1])
+                dst = int(row[2])
+                relation = int(row[3])
+                if src not in node_ids:
+                    node_ids[src] = unique_id
+                    unique_id += 1
+                if dst not in node_ids:
+                    node_ids[dst] = unique_id
+                    unique_id += 1
+                u = node_ids[src]
+                i = node_ids[dst]
+                u_list[idx - 1] = u
+                i_list[idx - 1] = i
+                ts_list[idx - 1] = ts
+                idx_list[idx - 1] = idx
+                w_list[idx - 1] = float(1)
+                edge_type[idx - 1] = relation
+                idx += 1
+    return (
+        pd.DataFrame(
+            {
+                "u": u_list,
+                "i": i_list,
+                "ts": ts_list,
+                "label": label_list,
+                "idx": idx_list,
+                "w": w_list,
+                "edge_type": edge_type,
+            }
+        ),
+        feat_l,
+        node_ids,
+    )
+
+"""
+functions for tkgl-wikidata dataset
+"""
+def csv_to_wikidata(
+    fname: str,
+) -> pd.DataFrame:
+    r"""
+    used by tkgl-wikidata and tkgl-smallpedia
+    convert the raw .csv data to pandas dataframe and numpy array
+    input .csv file format should be: timestamp, head, tail, relation type
+    Args:
+        fname: the path to the raw data
+    """
+    feat_size = 1
+    num_lines = sum(1 for line in open(fname)) - 1
+    vprint(f"number of lines counted: {num_lines} in {fname}")
+    u_list = np.zeros(num_lines)
+    i_list = np.zeros(num_lines)
+    ts_list = np.zeros(num_lines)
+    label_list = np.zeros(num_lines)
+    edge_type = np.zeros(num_lines)
+    feat_l = np.zeros((num_lines, feat_size))
+    idx_list = np.zeros(num_lines)
+    w_list = np.zeros(num_lines)
+    node_ids = {}
+    edge_type_ids = {}
+    unique_id = 0
+    et_id = 0
+
+    with open(fname, "r") as csv_file:
+        csv_reader = csv.reader(csv_file, delimiter=",")
+        idx = 0
+        #timestamp, head, tail, relation type
+        for row in tqdm(csv_reader):
+            if idx == 0:
+                idx += 1
+                continue
+            else:
+                ts = int(row[0]) #converted to year already
+                src = row[1]
+                dst = row[2]
+                relation = row[3]
+                if src not in node_ids:
+                    node_ids[src] = unique_id
+                    unique_id += 1
+                if dst not in node_ids:
+                    node_ids[dst] = unique_id
+                    unique_id += 1
+                if relation not in edge_type_ids:
+                    edge_type_ids[relation] = et_id
+                    et_id += 1
+                u = node_ids[src]
+                i = node_ids[dst]
+                u_list[idx - 1] = u
+                i_list[idx - 1] = i
+                ts_list[idx - 1] = ts
+                idx_list[idx - 1] = idx
+                w_list[idx - 1] = float(1)
+                edge_type[idx - 1] = edge_type_ids[relation]
+                idx += 1
+    return (
+        pd.DataFrame(
+            {
+                "u": u_list,
+                "i": i_list,
+                "ts": ts_list,
+                "label": label_list,
+                "idx": idx_list,
+                "w": w_list,
+                "edge_type": edge_type,
+            }
+        ),
+        feat_l,
+        node_ids,
+    )
+
+
+def csv_to_staticdata(
+    fname: str,
+    node_ids: dict,
+) -> pd.DataFrame:
+    r"""
+    used by tkgl-wikidata and tkgl-smallpedia
+    convert the raw .csv data to pandas dataframe and numpy array for static knowledge edges
+    input .csv file format should be: head, tail, relation type
+    Args:
+        fname: the path to the raw data
+        node_ids: dictionary of node names mapped to integer node ids
+    """
+    num_lines = sum(1 for line in open(fname)) - 1
+    vprint(f"number of lines counted: {num_lines} in {fname}")
+    u_list = np.zeros(num_lines)
+    i_list = np.zeros(num_lines)
+    edge_type = np.zeros(num_lines)
+    edge_type_ids = {}
+    out_dict = {}
+
+    with open(fname, "r") as csv_file:
+        csv_reader = csv.reader(csv_file, delimiter=",")
+        idx = 0
+        #timestamp, head, tail, relation type
+        for row in tqdm(csv_reader):
+            if idx == 0:
+                idx += 1
+                continue
+            else:
+                src = row[0]
+                dst = row[1]
+                relation = row[2]
+                if src not in node_ids:
+                    node_ids[src] = len(node_ids)
+                if dst not in node_ids:
+                    node_ids[dst] = len(node_ids)
+                if relation not in edge_type_ids:
+                    edge_type_ids[relation] = len(edge_type_ids)
+                u = node_ids[src]
+                i = node_ids[dst]
+                u_list[idx - 1] = u
+                i_list[idx - 1] = i                
+                edge_type[idx - 1] = edge_type_ids[relation]
+                idx += 1
+
+    out_dict["head"] = u_list
+    out_dict["tail"] = i_list
+    out_dict["edge_type"] = edge_type
+    return out_dict, node_ids
+
+
+
+
+
+
+"""
+functions for tkgl-polecat, tkgl-icews dataset
+"""
+def csv_to_tkg_data(
+    fname: str,
+) -> pd.DataFrame:
+    r"""
+    used by tkgl-polecat
+    convert the raw .csv data to pandas dataframe and numpy array
+    input .csv file format should be: timestamp, head, tail, relation type
+    Args:
+        fname: the path to the raw data
+    """
+    feat_size = 1
+    num_lines = sum(1 for line in open(fname)) - 1
+    vprint(f"number of lines counted: {num_lines} in {fname}")
+    u_list = np.zeros(num_lines)
+    i_list = np.zeros(num_lines)
+    ts_list = np.zeros(num_lines)
+    label_list = np.zeros(num_lines)
+    edge_type = np.zeros(num_lines)
+    feat_l = np.zeros((num_lines, feat_size))
+    idx_list = np.zeros(num_lines)
+    w_list = np.zeros(num_lines)
+    node_ids = {}
+    unique_id = 0
+
+    with open(fname, "r") as csv_file:
+        csv_reader = csv.reader(csv_file, delimiter=",")
+        idx = 0
+        #timestamp, head, tail, relation type
+        for row in tqdm(csv_reader):
+            if idx == 0:
+                idx += 1
+                continue
+            else:
+                ts = int(row[0]) #converted to UNIX timestamp already 
+                src = int(row[1])
+                dst = int(row[2])
+                relation = int(row[3])
+                if src not in node_ids:
+                    node_ids[src] = unique_id
+                    unique_id += 1
+                if dst not in node_ids:
+                    node_ids[dst] = unique_id
+                    unique_id += 1
+                u = node_ids[src]
+                i = node_ids[dst]
+                u_list[idx - 1] = u
+                i_list[idx - 1] = i
+                ts_list[idx - 1] = ts
+                idx_list[idx - 1] = idx
+                w_list[idx - 1] = float(1)
+                edge_type[idx - 1] = relation
+                idx += 1
+    return (
+        pd.DataFrame(
+            {
+                "u": u_list,
+                "i": i_list,
+                "ts": ts_list,
+                "label": label_list,
+                "idx": idx_list,
+                "w": w_list,
+                "edge_type": edge_type,
+            }
+        ),
+        feat_l,
+        node_ids,
+    )
+
+
+
 
 """
 functions for wikipedia dataset
 ---------------------------------------
 """
-
-
 def load_edgelist_wiki(fname: str) -> pd.DataFrame:
     """
     loading wikipedia dataset into pandas dataframe
@@ -48,14 +440,13 @@ def load_edgelist_trade(fname: str, label_size=255):
     """
     feat_size = 1
     num_lines = sum(1 for line in open(fname)) - 1
-    print("number of lines counted", num_lines)
+
     u_list = np.zeros(num_lines)
     i_list = np.zeros(num_lines)
     ts_list = np.zeros(num_lines)
     feat_l = np.zeros((num_lines, feat_size))
     idx_list = np.zeros(num_lines)
     w_list = np.zeros(num_lines)
-    #print("numpy allocated")
     node_ids = {}  # dictionary for node ids
     node_uid = 0
 
@@ -80,13 +471,12 @@ def load_edgelist_trade(fname: str, label_size=255):
 
                 u = node_ids[u]
                 i = node_ids[v]
-                feat = np.array([w])
                 u_list[idx - 1] = u
                 i_list[idx - 1] = i
                 ts_list[idx - 1] = ts
                 idx_list[idx - 1] = idx
                 w_list[idx - 1] = w
-                feat_l[idx - 1] = feat
+                feat_l[idx - 1] = np.array([w])
                 idx += 1
 
     return (
@@ -142,6 +532,104 @@ def load_trade_label_dict(
         return node_label_dict
 
 
+"""
+functions for tgbn-token
+---------------------------------------
+"""
+
+def load_edgelist_token(
+    fname: str,
+    label_size: int = 1001,
+) -> pd.DataFrame:
+    """
+    load the edgelist into pandas dataframe
+    also outputs index for the user nodes and genre nodes
+    Parameters:
+        fname: str, name of the input file
+        label_size: int, number of genres
+    Returns:
+        df: a pandas dataframe containing the edgelist data
+    """
+    feat_size = 2
+    num_lines = sum(1 for line in open(fname)) - 1
+    vprint("there are ", num_lines, " lines in the raw data")
+    u_list = np.zeros(num_lines)
+    i_list = np.zeros(num_lines)
+    ts_list = np.zeros(num_lines)
+    label_list = np.zeros(num_lines)
+    feat_l = np.zeros((num_lines, feat_size))
+    idx_list = np.zeros(num_lines)
+    w_list = np.zeros(num_lines)
+
+    node_ids = {}
+    rd_dict = {}
+    node_uid = label_size  # node ids start after all the genres
+    sr_uid = 0
+
+    with open(fname, "r") as csv_file:
+        csv_reader = csv.reader(csv_file, delimiter=",")
+        idx = 0
+        # [timestamp,user_address,token_address,value,IsSender]
+        for row in tqdm(csv_reader):
+            if idx == 0:
+                idx += 1
+            else:
+                ts = row[0]
+                src = row[1]
+                token = row[2]
+                w = float(row[3])
+                attr = float(row[4])
+                if src not in node_ids:
+                    node_ids[src] = node_uid
+                    node_uid += 1
+                if token not in rd_dict:
+                    rd_dict[token] = sr_uid
+                    sr_uid += 1
+                u = node_ids[src]
+                i = rd_dict[token]
+                u_list[idx - 1] = u
+                i_list[idx - 1] = i
+                ts_list[idx - 1] = ts
+                idx_list[idx - 1] = idx
+                w_list[idx - 1] = w
+                feat_l[idx - 1] = np.array([w,attr])
+                idx += 1
+
+        return (
+            pd.DataFrame(
+                {
+                    "u": u_list,
+                    "i": i_list,
+                    "ts": ts_list,
+                    "label": label_list,
+                    "idx": idx_list,
+                    "w": w_list,
+                }
+            ),
+            feat_l,
+            node_ids,
+            rd_dict,
+        )
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 """
 functions for subreddits dataset
 ---------------------------------------
@@ -161,10 +649,9 @@ def load_edgelist_sr(
     Returns:
         df: a pandas dataframe containing the edgelist data
     """
-    feat_size = 2
+    feat_size = 1 #2
     num_lines = sum(1 for line in open(fname)) - 1
-    #print("number of lines counted", num_lines)
-    print("there are ", num_lines, " lines in the raw data")
+    vprint("there are ", num_lines, " lines in the raw data")
     u_list = np.zeros(num_lines)
     i_list = np.zeros(num_lines)
     ts_list = np.zeros(num_lines)
@@ -189,7 +676,7 @@ def load_edgelist_sr(
                 ts = row[0]
                 src = row[1]
                 subreddit = row[2]
-                num_words = int(row[3])
+                #num_words = int(row[3])
                 score = int(row[4])
                 if src not in node_ids:
                     node_ids[src] = node_uid
@@ -205,7 +692,7 @@ def load_edgelist_sr(
                 ts_list[idx - 1] = ts
                 idx_list[idx - 1] = idx
                 w_list[idx - 1] = w
-                feat_l[idx - 1] = np.array([num_words, score])
+                feat_l[idx - 1] = np.array([w])
                 idx += 1
 
         return (
@@ -232,7 +719,6 @@ def load_labels_sr(
 ):
     """
     load the node labels for subreddit dataset
-    #TODO can be further optimized when using numpy and not appending
     """
     if not osp.exists(fname):
         raise FileNotFoundError(f"File not found at {fname}")
@@ -340,8 +826,7 @@ def csv_to_pd_data_rc(
     """
     feat_size = 2  # 1 for subreddit, 1 for num words
     num_lines = sum(1 for line in open(fname)) - 1
-    #print("number of lines counted", num_lines)
-    print("there are ", num_lines, " lines in the raw data")
+    vprint("there are ", num_lines, " lines in the raw data")
     u_list = np.zeros(num_lines)
     i_list = np.zeros(num_lines)
     ts_list = np.zeros(num_lines)
@@ -386,7 +871,7 @@ def csv_to_pd_data_rc(
                 w_list[idx - 1] = w
                 feat_l[idx - 1] = np.array([num_words])
                 idx += 1
-    print("there are ", len(node_ids), " unique nodes")
+    vprint("there are ", len(node_ids), " unique nodes")
 
     return (
         pd.DataFrame(
@@ -408,8 +893,6 @@ def csv_to_pd_data_rc(
 functions for stablecoin
 -------------------------------------------
 """
-
-
 def csv_to_pd_data_sc(
     fname: str,
 ) -> pd.DataFrame:
@@ -426,7 +909,7 @@ def csv_to_pd_data_sc(
     """
     feat_size = 1
     num_lines = sum(1 for line in open(fname)) - 1
-    print("number of lines counted", num_lines)
+    vprint(f"number of lines counted: {num_lines} in {fname}")
     u_list = np.zeros(num_lines)
     i_list = np.zeros(num_lines)
     ts_list = np.zeros(num_lines)
@@ -434,7 +917,6 @@ def csv_to_pd_data_sc(
     feat_l = np.zeros((num_lines, feat_size))
     idx_list = np.zeros(num_lines)
     w_list = np.zeros(num_lines)
-    print("numpy allocated")
     node_ids = {}
     unique_id = 0
 
@@ -491,7 +973,6 @@ def csv_to_pd_data_sc(
         node_ids,
     )
 
-
 """
 functions for opensky
 -------------------------------------------
@@ -522,12 +1003,11 @@ def convert_str2int(
     return out
 
 
-#! panda dataframe can't take numpy 2d arrays
 def csv_to_pd_data(
     fname: str,
 ) -> pd.DataFrame:
     r"""
-    currently used by open sky dataset
+    currently used by tgbl-flight dataset
     convert the raw .csv data to pandas dataframe and numpy array
     input .csv file format should be: timestamp, node u, node v, attributes
     Args:
@@ -535,7 +1015,7 @@ def csv_to_pd_data(
     """
     feat_size = 16
     num_lines = sum(1 for line in open(fname)) - 1
-    print("number of lines counted", num_lines)
+    vprint(f"number of lines counted: {num_lines} in {fname}")
     u_list = np.zeros(num_lines)
     i_list = np.zeros(num_lines)
     ts_list = np.zeros(num_lines)
@@ -543,10 +1023,9 @@ def csv_to_pd_data(
     feat_l = np.zeros((num_lines, feat_size))
     idx_list = np.zeros(num_lines)
     w_list = np.zeros(num_lines)
-    print("numpy allocated")
-    TIME_FORMAT = "%Y-%m-%d"  # 2019-01-01
     node_ids = {}
     unique_id = 0
+    ts_format = None
 
     with open(fname, "r") as csv_file:
         csv_reader = csv.reader(csv_file, delimiter=",")
@@ -558,8 +1037,26 @@ def csv_to_pd_data(
                 continue
             else:
                 ts = row[0]
-                date_cur = datetime.strptime(ts, TIME_FORMAT)
-                ts = float(date_cur.timestamp())
+                if ts_format is None:
+                    if (ts.isdigit()):
+                        ts_format = True
+                    else:
+                        ts_format = False
+                
+                if ts_format:
+                    ts = float(int(ts)) #unix timestamp already
+                else:
+                    #convert to unix timestamp
+                    TIME_FORMAT = "%Y-%m-%d"
+                    date_cur = datetime.datetime.strptime(ts, TIME_FORMAT)
+                    ts = float(date_cur.timestamp())
+                    # TIME_FORMAT = "%Y-%m-%d" # 2019-01-01
+                    # date_cur  = date.fromisoformat(ts)
+                    # dt = datetime.datetime.combine(date_cur, datetime.datetime.min.time())
+                    # dt = dt.replace(tzinfo=datetime.timezone.edt)
+                    # ts = float(dt.timestamp())
+
+
                 src = row[1]
                 dst = row[2]
 
@@ -692,7 +1189,6 @@ def process_node_feat(
                     node_feat[node_id] = final
     return node_feat
 
-
 """
 functions for un trade
 -------------------------------------------
@@ -733,8 +1229,7 @@ def clean_rows(
 
             e = line.strip().split(",")
             if len(e) > 4:
-                print(e)
-                raise ValueError("line has more than 4 elements")
+                raise ValueError(f"line has more than 4 elements: {e}")
             outf.write(line)
 
     outf.close()
@@ -757,14 +1252,13 @@ def load_edgelist_datetime(fname, label_size=514):
     """
     feat_size = 1
     num_lines = sum(1 for line in open(fname)) - 1
-    print("number of lines counted", num_lines)
+    vprint(f"number of lines counted: {num_lines} in {fname}")
     u_list = np.zeros(num_lines)
     i_list = np.zeros(num_lines)
     ts_list = np.zeros(num_lines)
     feat_l = np.zeros((num_lines, feat_size))
     idx_list = np.zeros(num_lines)
     w_list = np.zeros(num_lines)
-    #print("numpy allocated")
     node_ids = {}  # dictionary for node ids
     label_ids = {}  # dictionary for label ids
     node_uid = label_size  # node ids start after the genre nodes
@@ -789,18 +1283,17 @@ def load_edgelist_datetime(fname, label_size=514):
                 if genre not in label_ids:
                     label_ids[genre] = label_uid
                     if label_uid >= label_size:
-                        print("id overlap, terminate")
+                        vprint("id overlap, terminate")
                     label_uid += 1
 
                 u = node_ids[user_id]
                 i = label_ids[genre]
-                feat = np.zeros((1))
                 u_list[idx - 1] = u
                 i_list[idx - 1] = i
                 ts_list[idx - 1] = ts
                 idx_list[idx - 1] = idx
                 w_list[idx - 1] = w
-                feat_l[idx - 1] = feat
+                feat_l[idx - 1] = np.asarray([w])
                 idx += 1
 
     return (
@@ -842,66 +1335,6 @@ functions for wikipedia and un_trade
 -------------------------------------------
 """
 
-
-def _to_pd_data(
-    fname: str,
-):
-    r"""
-    convert the raw .csv data to pandas dataframe and numpy array
-    input .csv file format should be: timestamp, node u, node v, weight w,
-    Args:
-        fname: the path to the raw data
-    """
-    u_list, i_list, ts_list, label_list = [], [], [], []
-    feat_l = []
-    idx_list = []
-    w_list = []
-
-    with open(fname) as f:
-        s = next(f)
-        node_ids = {}
-        unique_id = 0
-        for idx, line in enumerate(f):
-            e = line.strip().split(",")
-            if len(e) > 4:
-                print(e)
-            # convert to integer node id
-            ts = float(e[0])
-
-            if e[1] not in node_ids:
-                node_ids[e[1]] = unique_id
-                unique_id += 1
-            if e[2] not in node_ids:
-                node_ids[e[2]] = unique_id
-                unique_id += 1
-
-            u = node_ids[e[1]]
-            i = node_ids[e[2]]
-            w = float(e[3])
-
-            label = 0
-            feat = np.zeros((1))
-
-            u_list.append(u)
-            i_list.append(i)
-            ts_list.append(ts)
-            label_list.append(label)
-            idx_list.append(idx)
-            feat_l.append(feat)
-            w_list.append(w)
-
-    return pd.DataFrame(
-        {
-            "u": u_list,
-            "i": i_list,
-            "ts": ts_list,
-            "label": label_list,
-            "idx": idx_list,
-            "w": w_list,
-        }
-    ), np.array(feat_l)
-
-
 def reindex(
     df: pd.DataFrame,
     bipartite: Optional[bool] = False,
@@ -932,11 +1365,4 @@ def reindex(
     return new_df
 
 
-if __name__ == "__main__":
-    # """
-    # clean rows for un trade dataset
-    # """
-    # fname = "/mnt/c/Users/sheny/Desktop/TGB/tgb/datasets/un_trade/un_trade.csv"
-    # outname = "/mnt/c/Users/sheny/Desktop/TGB/tgb/datasets/un_trade/un_trade_cleaned.csv"
-    # clean_rows(fname, outname)
-    print("hi")
+    
